==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_fields/RELIABILITYRANKINGID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour RELIABILITYRANKINGID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="RELIABILITYRANKINGID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RELIABILITYRANKINGCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RELIABILITYRANKINGREVISION"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RELIABILITYRANKINGID_Type", propOrder = {
    "reliabilityrankingcode",
    "reliabilityrankingrevision",
    "organizationid",
    "description"
})
public class RELIABILITYRANKINGID_Type {

    @XmlElement(name = "RELIABILITYRANKINGCODE", required = true)
    protected String reliabilityrankingcode;
    @XmlElement(name = "RELIABILITYRANKINGREVISION")
    protected long reliabilityrankingrevision;
    @XmlElement(name = "ORGANIZATIONID", required = true)
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Obtient la valeur de la propriété reliabilityrankingcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRELIABILITYRANKINGCODE() {
        return reliabilityrankingcode;
    }

    /**
     * Définit la valeur de la propriété reliabilityrankingcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRELIABILITYRANKINGCODE(String value) {
        this.reliabilityrankingcode = value;
    }

    /**
     * Obtient la valeur de la propriété reliabilityrankingrevision.
     * 
     */
    public long getRELIABILITYRANKINGREVISION() {
        return reliabilityrankingrevision;
    }

    /**
     * Définit la valeur de la propriété reliabilityrankingrevision.
     * 
     */
    public void setRELIABILITYRANKINGREVISION(long value) {
        this.reliabilityrankingrevision = value;
    }

    /**
     * Obtient la valeur de la propriété organizationid.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Définit la valeur de la propriété organizationid.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/RELIABILITYRANKINGID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for RELIABILITYRANKINGID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="RELIABILITYRANKINGID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RELIABILITYRANKINGCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RELIABILITYRANKINGREVISION"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RELIABILITYRANKINGID_Type", propOrder = {
    "reliabilityrankingcode",
    "reliabilityrankingrevision",
    "organizationid",
    "description"
})
public class RELIABILITYRANKINGID_Type {

    @XmlElement(name = "RELIABILITYRANKINGCODE", required = true)
    protected String reliabilityrankingcode;
    @XmlElement(name = "RELIABILITYRANKINGREVISION")
    protected long reliabilityrankingrevision;
    @XmlElement(name = "ORGANIZATIONID", required = true)
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Gets the value of the reliabilityrankingcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRELIABILITYRANKINGCODE() {
        return reliabilityrankingcode;
    }

    /**
     * Sets the value of the reliabilityrankingcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRELIABILITYRANKINGCODE(String value) {
        this.reliabilityrankingcode = value;
    }

    /**
     * Gets the value of the reliabilityrankingrevision property.
     * 
     */
    public long getRELIABILITYRANKINGREVISION() {
        return reliabilityrankingrevision;
    }

    /**
     * Sets the value of the reliabilityrankingrevision property.
     * 
     */
    public void setRELIABILITYRANKINGREVISION(long value) {
        this.reliabilityrankingrevision = value;
    }

    /**
     * Gets the value of the organizationid property.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Sets the value of the organizationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}
